function ss_band_plot(f, a, d, fo, fs, f1, f2, sym)
% SS_BAND_PLOT - Plot filter specification
%   
% Inputs: 
% f - frequency band edges in normalized frequency [-1..1]
% a - amplitude of bands
% d - ripple weighting
% fo - offset absolute frequency
% fs - sampling frequency
% f1, f2 - upper lower absolute frequencies to plot
% sym - flag whether response is symmetric
%    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Spectral-Spatial RF Pulse Design for MRI and MRSI MATLAB Package
%
% Authors: Adam B. Kerr and Peder E. Z. Larson
%
% (c)2007-2011 Board of Trustees, Leland Stanford Junior University and
%	The Regents of the University of California. 
% All Rights Reserved.
%
% Please see the Copyright_Information and README files included with this
% package.  All works derived from this package must be properly cited.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% $Header: /home/adam/cvsroot/src/ss/ss_band_plot.m,v 1.5 2012/02/01 00:41:23 peder Exp $
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% $Log: ss_band_plot.m,v $
% Revision 1.5  2012/02/01 00:41:23  peder
% Added standard copyright notice to all functions
%
% Revision 1.4  2007/09/08 02:37:29  adam
% Fixing up demo script
% Fixed up ss_plot to look a little better
%
% Revision 1.3  2007-09-07 17:26:47  adam
% Integrating ss_spect_correct, as well as EP support, almost(!!) working
%
% Revision 1.2  2007-09-05 20:59:24  adam
% Add water/fat examples
% First pass at adding symmetric filter design---still needs some work
% Get rid of SLR trial in EPI spectral correct routine---will fix later
%
% Revision 1.1.1.1  2007-08-29 15:58:20  adam
% Starting sources
%
% Revision 1.1.1.1  2007-08-29 15:45:32  adam
% Starting sources
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    % Exit if frequency vector is empty
    %
    if isempty(f), 
	fprintf(1,'No frequency bands to plot\n');
	return;
    end;
    
    if sym, 
	fmod = f;
	f = [-fmod(end:-1:1) fmod];
	a = [a(end:-1:1) a];
	d = [d(end:-1:1) d];
    end;

    % Plot unaliased frequency bands
    %
    nf = length(f)/2;
    figure;
    subplot(211);
    hold on;
    for idx = 1:nf, 
	plot(f((idx*2-1):(idx*2))*fs/2+fo, [a(idx) a(idx)]);
	plot(f((idx*2-1):(idx*2))*fs/2+fo, [a(idx) a(idx)] + d(idx), '--');
	plot(f((idx*2-1):(idx*2))*fs/2+fo, [a(idx) a(idx)] - d(idx), ...
	     '--');
    end;
    grid;
    title('Unaliased Filter Specification');
    xlabel('Frequency');
    ylabel('Amplitude Response');
    
    % Plot absolute frequency response
    %
    subplot(212);
    hold on;

    % Find what repeating responses need to be considered
    %
    low_mult = ceil(((fo-f1)-fs/2) / fs);
    hi_mult = ceil(((f2-fo)-fs/2) / fs);
    for mult = -low_mult:hi_mult, 
	foff = fo + fs*mult;
	for idx = 1:nf, 
	    % Get repeating band edge
	    %
	    f_l = (f(idx*2-1) * fs/2) + foff;
	    f_u = (f(idx*2) * fs/2) + foff;
	    
	    % Plot if in bounds
	    %
	    f_l = min(max(f_l, f1), f2);
	    f_u = min(max(f_u, f1), f2);
	    if (f_l ~= f_u), 
		plot([f_l f_u], [a(idx) a(idx)]);
		plot([f_l f_u], [a(idx) a(idx)] + d(idx), '--');
		plot([f_l f_u], [a(idx) a(idx)] - d(idx), '--');
	    end;
	end;
    end;
    grid;
    title(sprintf('Filter Specification - Fs: %6.1f Hz', fs));
    xlabel('Frequency');
    ylabel('Amplitude Response');

    
    
    
