function mxy = ss_response_mxy(g,rf,z,f,ts,gamma)
% SS_RESPONSE_MXY - Get Mxy response at given z, f position/frequency
%
% mxy = ss_response_mxy(g,rf,z,f,ts,gamma)
%
% Input
%    g - gradient, G/cm
%    rf - rf G
%    z - cm
%    f - frequency
%    ts - sampling time (s)
%    gamma - gyromagnetic ratio
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Spectral-Spatial RF Pulse Design for MRI and MRSI MATLAB Package
%
% Authors: Adam B. Kerr and Peder E. Z. Larson
%
% (c)2007-2011 Board of Trustees, Leland Stanford Junior University and
%	The Regents of the University of California. 
% All Rights Reserved.
%
% Please see the Copyright_Information and README files included with this
% package.  All works derived from this package must be properly cited.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% $Header: /home/adam/cvsroot/src/ss/ss_response_mxy.m,v 1.4 2012/02/01 00:41:23 peder Exp $
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% $Log: ss_response_mxy.m,v $
% Revision 1.4  2012/02/01 00:41:23  peder
% Added standard copyright notice to all functions
%
% Revision 1.3  2011/09/27 22:06:17  peder
% examples/*.m are all now working and updated.  minor fix to fir_minphase_power to catch error.  Added many comments to functions
%
% Revision 1.2  2007-09-08 04:25:07  adam
% Forgot header
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    
    % Convert RF to a rotation in radians
    %
    rf_rot = 2 * pi * gamma * rf * ts;

    % Build gradient that gives rotation  
    % in radians when scaled by "f" (off-resonance in Hz) 
    %
    gf_rot = 2 * pi * ts * ones(size(g));
    
    % Convert gradient to a rotation in radians
    % when scaled by "z"
    %
    gz_rot = 2 * pi * gamma * g * ts;
    
    % Get Mxy now
    %
    [a b] = abr(rf_rot, gz_rot+i*gf_rot, z, f);
    mxy = ab2ex(a, b);
    

    
    
    
